"""Lemmatize nltk pos tag to wodnet tag."""
from typing import List

import nltk
from nltk.stem import WordNetLemmatizer
from nltk.corpus import wordnet

lemmatizer = WordNetLemmatizer()


def convert_tag(tag: str) -> str:
    """Convert nltk pos tag to wodnet tag."""
    res = tag[0].lower()

    if res in ["j"]:
        res = "a"
    if res not in ["a", "v", "n", "r"]:
        res = "n"

    return res


def normalize(text: str) -> List[str]:
    """Lemmatize text.

    [lemmatize(word, convert_tag(tag)) for word, tag in pos_tag(word_tokenize(text))]

    >>> text = 'I am loving it'
    >>> normalize('I am loving it')[1] in ["be"]
    True
    """
    words = nltk.word_tokenize(text)
    tagged = nltk.pos_tag(words)

    res = []
    for word, tag in tagged:
        _ = convert_tag(tag)
        res.append(lemmatizer.lemmatize(word, _))

    return res



"""Calculate bm scores of two lists."""
from typing import List, Union
import numpy as np

import nltk
from rank_bm25 import BM25Okapi

from loguru import logger

from light_scores.normalize import normalize


PUNCTUATION = '!"#$%&\'()*+,-./:;<=>?@[\\]^_`{|}~'


def light_scores(
    text_en: Union[str, List[str]],
    text_tr: Union[str, List[str]],
    norm: bool = False,
    remove_stopwords: bool = False,
    clean: bool = True,
    lower: bool = True,
) -> np.ndarray:
    """Calculate bm scores of two lists.

    norm: bool = False
    remove_stopwords: bool = False
    clean: bool = True
    lower: bool = True
    """
    if isinstance(text_en, str):
        text_en = [elm.strip() for elm in text_en.splitlines() if elm.strip()]
    if isinstance(text_tr, str):
        text_tr = [elm.strip() for elm in text_tr.splitlines() if elm.strip()]

    # List of str

    def seg_to_words(lines, norm=True):
        if isinstance(lines, str):
            lines = [lines]
        res = []
        for line in lines:
            if lower:
                line = line.lower()
            if norm:
                words = normalize(line)
            else:
                words = nltk.word_tokenize(line)
            res.append(words)

        return res

    # tokenize to words, normalize if norm is True
    token_list_en = seg_to_words(text_en, norm)
    token_list_tr = seg_to_words(text_tr, norm)

    # logger.debug(f" befoe stopwords removed: {token_list_en}")

    # lowercase, clean, split,
    if remove_stopwords:
        # remove stop words
        from nltk.corpus import stopwords
        stop_words_eng = set(stopwords.words('english'))

        def remove_(words_lines: List[List[str]]) -> List[str]:
            res = []
            for line in words_lines:
                _ = [w for w in line if w.lower() not in stop_words_eng]
                res.append(_)
            return res

        token_list_en = remove_(token_list_en)
        token_list_tr = remove_(token_list_tr)

        logger.debug(f" stopwords removed: {token_list_en}")

    tokenized_corpus = token_list_en
    logger.debug(f" tokenized_corpus: {tokenized_corpus}")

    logger.debug(f" query: {token_list_tr}")

    # tokenized_corpus = []
    if not tokenized_corpus:
        raise Exception(" tokenized_corpus is empty, something has gone awry.")

    bm25 = BM25Okapi(tokenized_corpus)

    corr_mat = []
    for idx, sent in enumerate(token_list_tr):
        corr = bm25.get_scores(sent)
        corr_mat.append(corr)

    # return np.array([1])
    return np.array(corr_mat)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['light_scores']

package_data = \
{'': ['*']}

install_requires = \
['loguru>=0.5.3,<0.6.0', 'nltk>=3.6.2,<4.0.0', 'rank-bm25>=0.2.1,<0.3.0']

setup_kwargs = {
    'name': 'light-scores',
    'version': '0.1.0',
    'description': '',
    'long_description': '# light_scores\n<!--- light_scores  light_scores  light_scores light_scores --->\n[![tests](https://github.com/ffreemt/light_scores/actions/workflows/routine-tests.yml/badge.svg)][![python](https://img.shields.io/static/v1?label=python+&message=3.7%2B&color=blue)](https://img.shields.io/static/v1?label=python+&message=3.7%2B&color=blue)[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)[![PyPI version](https://badge.fury.io/py/light_scores.svg)](https://badge.fury.io/py/light_scores)\n\nCalculate bm25 matrix of two lists\n\n## Usage\n\n```python\nfrom light_scores.light_scores import light_scores\n\nres = await light_scores("test me")\nprint(res)\n# \'考我 试探我 测试我 试探\'\n\nprint(await light_scores("test me", to_lang="de"))',
    'author': 'freemt',
    'author_email': None,
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/ffreemt/light-scores',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
